@@ -8,7 +8,7 @@ from bentoml.utils.lazy_loader import LazyLoader
 from jinja2 import Environment, FileSystemLoader
 from kubernetes import client, config
 
-import from_yaml from bentoutils.kubeutil
+from bentoutils.kubeutil import from_yaml
 
 
 @click.command()
